/* Copyright 2000 by the Massachusetts Institute of Technology.
 *
 * Permission to use, copy, modify, and distribute this
 * software and its documentation for any purpose and without
 * fee is hereby granted, provided that the above copyright
 * notice appear in all copies and that both that copyright
 * notice and this permission notice appear in supporting
 * documentation, and that the name of M.I.T. not be used in
 * advertising or publicity pertaining to distribution of the
 * software without specific, written prior permission.
 * M.I.T. makes no representations about the suitability of
 * this software for any purpose.  It is provided "as is"
 * without express or implied warranty.
 */

#include <stdio.h>
#include <string.h>
#include "nmcalc.h"

int main(int argc, char **argv) {
  char *ptr;
  struct mask *m;

  if ((argc < 2) || (argc > 4)) {
    printf("nmcalc version %s\n\n", VERSION);
    printf("usage: nmcalc <mask> [ipaddr]\n");
    printf("   mask can be:\n");
    printf("     dotted quad  like  255.255.255.192\n");
    printf("     CIDR block   like  /26\n");
    printf("     bitstring    like  11111111111111111111111111000000\n");
    exit(0);
  }
  
  if (strchr(argv[1], '.')) {
    /* quad string */
    m=mask_from_quadstring(argv[1]);
  } else if (argv[1][0] == '/') {
    /* cidr */
    m=mask_from_cidrstring(argv[1]);
  } else {
    /* bitstring */
    m=mask_from_bitstring(argv[1]);
  }

  if (!m) {
    /* printf("Invalid netmask\n"); */
    return(1);
  }

  printf("mask   : %s\n", mask_to_quadstring(m));
  printf("wild   : %s\n", mask_to_wildstring(m));
  if ((ptr=mask_to_cidrstring(m))!=NULL) {
    printf("cidr   : %s\n", ptr);
  } else {
    printf("cidr   : This netmask could not be represented as CIDR\n");
  }
  printf("#addrs : %i\n", mask_num_addresses(m));
  printf("bitstr : %s\n", mask_to_nicebitstring(m));
  
  if (argc==3) {
    ptr=mask_netlowaddr(m, argv[2]);
    if (ptr) {
      printf("lowaddr: %s\n", ptr);
    } else {
      exit(1);
    }
      
    ptr=mask_nethighaddr(m, argv[2]);
    if (ptr) {
      printf("hiaddr : %s\n", ptr);
    } else {
      exit(1);
    }
  }
  exit(0);
}
